@@ -12,7 +12,7 @@ use Time::Crontab;
 use Date::Format 'time2str';
 use Encode 'encode';
 
-our $VERSION = '1.12'; # VERSION
+our $VERSION = '1.13'; # VERSION
 
 sub new {
     my $class = shift;
@@ -121,6 +121,9 @@ sub _parent {
 
     eval {
         while ( my $line = $self->{socket}->getline ) {
+            $line =~ s/\003\d{2}(?:,\d{2})?//g; # remove IRC color codes
+            $line =~ tr/\000-\037//d;           # remove all control characters
+
             $self->note($line);
             chomp($line);
 
@@ -553,7 +556,7 @@ Bot::IRC - Yet Another IRC Bot
 
 =head1 VERSION
 
-version 1.12
+version 1.13
 
 =for markdown [![Build Status](https://travis-ci.org/gryphonshafer/Bot-IRC.svg)](https://travis-ci.org/gryphonshafer/Bot-IRC)
 [![Coverage Status](https://coveralls.io/repos/gryphonshafer/Bot-IRC/badge.png)](https://coveralls.io/r/gryphonshafer/Bot-IRC)
